@@ -43,6 +43,7 @@ class SocketStream(AsyncSocketStream):
                     self.stream,
                     ssl_context=ssl_context,
                     hostname=hostname.decode("ascii"),
+                    standard_compatible=False,
                 )
         except TimeoutError:
             raise ConnectTimeout from None
@@ -62,7 +63,7 @@ class SocketStream(AsyncSocketStream):
             except BrokenResourceError as exc:
                 raise ReadError from exc
             except EndOfStream:
-                raise ReadError("Server disconnected while attempting read") from None
+                return b""
 
     async def write(self, data: bytes, timeout: TimeoutDict) -> None:
         if not data:
